netapp_ontap.models.ndmp_connect API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved.

# Module `netapp_ontap.models.ndmp_connect`

Copyright © 2020 NetApp Inc. All rights reserved.

## Classes

`class NdmpConnectSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the NdmpConnect object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `address GET POST PATCH`

    Indicates the NDMP data connection address.

  `port GET POST PATCH`

    Indicates the NDMP data connection port.

    Example: 18600

  `type GET POST PATCH`

    Indicates the NDMP data connection type.